==> link_filebrowser-1.0.0.tar.gz: link_filebrowser/js/filebrowser-block.js <==
(function (Drupal, $, once) {
  'use strict';

  Drupal.behaviors.explorerblock = {
    attach: function (context, settings) {
      $(once('browser_block', '.browser-block', context)).each(function () {
        let url_scan = $(this).data('url_scan');
        url_scan += '?scan=' + $(this).data('folder');
        let that = $(this);
        $.get(url_scan, function (env) {
          function get(path) {
            var current = env;
            browser.walk(path, function (file) {
              current = current[file];
            });
            return current;
          }
          that.browse({
            root: '/',
            separator: '/',
            contextmenu: true,
            name: 'filestystem',
            refresh_timer: 0,
            dir: function (path) {
              let dir = get(path);
              var result;
              if ($.isPlainObject(dir)) {
                result = {files: [], dirs: []};
                Object.keys(dir).forEach(function (key) {
                  if (typeof dir[key] == 'string') {
                    result.files.push(key);
                  } else if ($.isPlainObject(dir[key])) {
                    result.dirs.push(key);
                  }
                });
              }
              return $.when(result); // resolved promise
            },
            open: function (filename) {
              var file = get(filename);
              if (typeof file == 'string') {
                let link = document.createElement('a');
                link.href = '/'+file.split('web/').pop();
                link.download = filename.split('/').pop();
                link.click();
                link.remove();
              }
            },
          });
          var browser = that.browse();
        });


      });
    }
  };
}(Drupal, jQuery, once));

==> link_filebrowser-1.0.1.tar.gz: link_filebrowser/js/filebrowser-block.js <==
(function (Drupal, $, once) {
  'use strict';

  Drupal.behaviors.explorerblock = {
    attach: function (context, settings) {
      $(once('browser_block', '.browser-block', context)).each(function () {
        let url_scan = $(this).data('url_scan');
        let all = $(this).data('all');
        var rootFolder = $(this).data('folder').replace('\\', '/');
        let that = $(this);
        $.post(url_scan, {directory: rootFolder, all: all}, function (env) {
          var current = {};
          function get(path) {
            current = env;
            browser.walk(path, function (file) {
              if (current[file] != undefined) {
                current = current[file];
              }
            });
            return current;
          }

          that.browse({
            root: '/',
            separator: '/',
            contextmenu: true,
            name: 'filestystem',
            refresh_timer: 0,
            dir: function (path) {
              let dir = get(path);
              var result = {files: [], dirs: []};
              if ($.isPlainObject(dir)) {
                Object.keys(dir).forEach(function (key) {
                  if (typeof dir[key] == 'string') {
                    result.files.push(key);
                  } else {
                    result.dirs.push(key);
                    if (current[key].length == 0) {
                      $.post(url_scan, {directory: path + '/' + key, root: rootFolder}, function (data) {
                        current[key] = data;
                      });
                    }
                  }
                });
              }
              return $.when(result); // resolved promise
            },
            open: function (filename) {
              var file = get(filename);
              if (typeof file == 'string') {
                let link = document.createElement('a');
                link.href = '/' + file.split('web/').pop();
                link.download = filename.split('/').pop();
                link.click();
                link.remove();
              }
            },
          });
          var browser = that.browse();
        });

      });
    }
  };
}(Drupal, jQuery, once));
